@@ -192,7 +192,7 @@ def process(uci, hbn, pwbe, year, ofilename, modulus, tablefmt):
         )
 
     if year is not None:
-        pdf = pd.DataFrame(pdf.ix["{0}-01-01".format(year), :]).T
+        pdf = pd.DataFrame(pdf.loc["{0}-01-01".format(year), :]).T
     pdf = pdf[[i for i in pdf.columns if "PERLND" in i or "IMPLND" in i]]
 
     mindex = [i.split("_") for i in pdf.columns]
@@ -570,7 +570,7 @@ def mapping(hbn, year=None, ofilename="", tablefmt="csv_nos", index_prefix=""):
         )
 
     if year is not None:
-        pdf = pd.DataFrame(pdf.ix["{0}-01-01".format(year), :]).T
+        pdf = pd.DataFrame(pdf.loc["{0}-01-01".format(year), :]).T
     pdf = pdf[[i for i in pdf.columns if "PERLND" in i or "IMPLND" in i]]
 
     mindex = [i.split("_") for i in pdf.columns]
